==> simple-react-data-grid-2.0.5.tgz: package/src/components/dataGrid/Table.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import orderBy from 'lodash/orderBy';

import { filterData, getFilterData } from '../.././utils/filterData';
import TableHeader from './TableHeader';
import TableBody from './TableBody';
import TableDrawer from './TableDrawer';
import TableFooter from './TableFooter';
import { getData, getNoOfPages } from '../.././utils/CommonUtils';
import '../../datagrid.css';
/*
 * The Table component for the grid which will render - TableDrawer, TableHeader, TableBody and TableFooter.
 * It will also handle the search, sort, filter and pagination functionality for the grid.
 *
 * @type {class}
 */
class Table extends Component {
  constructor(props) {
    super(props);
    this.state = {
      sortOrder: 'asc',
      currentPage: 1,
      data: this.props.data,
      recordsPerPage: this.props.gridState.recordsPerPage,
      appliedFilter: {},
    };
    this.onSearch = this.onSearch.bind(this);
    this.onSort = this.onSort.bind(this);
    this.onPagination = this.onPagination.bind(this);
    this.onFilterChange = this.onFilterChange.bind(this);
    this.handleReRenderButtonClick = this.handleReRenderButtonClick.bind(this);
  }


  handleReRenderButtonClick() {
    this.setState({
      appliedFilter: {},
      data: this.props.data,
    });
  }

  onFilterChange(inputValue) {
    this.setState({
      appliedFilter: { ...this.state.appliedFilter, [inputValue.selectedColumn]: inputValue.searchEntity },
      currentPage: 1,
    });
  }

  onSearch(searchInput) {
    const filterConfig = {
      searchEntity: searchInput.searchEntity,
      selectedColumn: searchInput.selectedColumn,
    };
    const searchData = getFilterData(filterConfig, this.props.data);
    this.setState({
      data: searchData,
      currentPage: 1,
    });
  }

  onSort(columnId) {
    if (this.state.sortOrder === 'asc') {
      const sortedData = orderBy(this.state.data, [columnId], ['asc']);
      this.setState({
        data: sortedData,
        sortOrder: 'desc',
      });
    } else {
      const sortedData = orderBy(this.state.data, [columnId], ['desc']);
      this.setState({
        data: sortedData,
        sortOrder: 'asc',
      });
    }
  }

  onPagination(value) {
    const noOfPages = getNoOfPages(this.state.data, this.props.gridState.recordsPerPage);
    if (value === 'lastPage' && this.state.currentPage < noOfPages) {
      this.setState({
        currentPage: noOfPages,
      });
    }
    if (value === 'firstPage') {
      this.setState({
        currentPage: 1,
      });
    }
    if (value === 'increment' && this.state.currentPage < noOfPages) {
      this.setState({
        currentPage: this.state.currentPage + 1,
      });
    } else if (value === 'decrement' && this.state.currentPage > 1) {
      this.setState({
        currentPage: this.state.currentPage - 1,
      });
    }
  }
  renderTableDrawer(data, position, configuredPosition) {
    if (position === configuredPosition) {
      return (
        <TableDrawer
          data={data}
          metaData={this.props.metaData}
          styles={this.props.styles}
          gridState={this.props.gridState}
          onPagination={this.onPagination}
          onSearch={this.onSearch}
          onSort={this.onSort}
          currentPage={this.state.currentPage}
          recordsPerPage={this.state.recordsPerPage}
          handleReRenderButtonClick={this.handleReRenderButtonClick}
        />
      );
    }

    return null;
  }

  render() {
    const { currentPage, data, recordsPerPage } = this.state;
    const filteredData = filterData(this.state.appliedFilter, this.state.data);
    const tableRowsData = getData({ data: filteredData, recordsPerPage, currentPage });
    return (
      <div className="table">
        {this.renderTableDrawer(filteredData, this.props.metaData.drawerPosition, 'top')}
        <div className="render-table" style={this.props.styles.gridTable}>
          <TableHeader
            metaData={this.props.metaData.headerConfig}
            styles={this.props.styles}
            onSort={this.onSort}
            onSearch={this.onSearch}
            onFilterChange={this.onFilterChange}
            appliedFilter={this.state.appliedFilter}
          />
          <TableBody
            tableData={tableRowsData}
            metaData={this.props.metaData}
            styles={this.props.styles}
          />
        </div>
        <TableFooter
          gridState={this.props.gridState}
          metaData={this.props.metaData}
          styles={this.props.styles}
        />
        {this.renderTableDrawer(filteredData, this.props.metaData.drawerPosition, 'bottom')}
      </div>
    );
  }
}

Table.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styles: PropTypes.object,
  gridState: PropTypes.object,
};

Table.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
  gridState: {},
};

export default Table;

==> simple-react-data-grid-2.0.8.tgz: package/src/components/dataGrid/Table.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import orderBy from 'lodash/orderBy';

import { filterData, getFilterData } from '../.././utils/filterData';
import TableHeader from './TableHeader';
import TableBody from './TableBody';
import TableDrawer from './TableDrawer';
import TableFooter from './TableFooter';
import { getData, getNoOfPages } from '../.././utils/CommonUtils';
import '../../datagrid.css';
/*
 * The Table component for the grid which will render - TableDrawer, TableHeader, TableBody and TableFooter.
 * It will also handle the search, sort, filter and pagination functionality for the grid.
 *
 * @type {class}
 */
class Table extends Component {
  constructor(props) {
    super(props);
    this.state = {
      sortOrder: 'asc',
      currentPage: 1,
      data: this.props.data,
      recordsPerPage: this.props.gridState.recordsPerPage,
      appliedFilter: {},
    };
    this.onSearch = this.onSearch.bind(this);
    this.onSort = this.onSort.bind(this);
    this.onPagination = this.onPagination.bind(this);
    this.onFilterChange = this.onFilterChange.bind(this);
    this.handleReRenderButtonClick = this.handleReRenderButtonClick.bind(this);
  }


  handleReRenderButtonClick() {
    this.setState({
      appliedFilter: {},
      data: this.props.data,
    });
  }

  onFilterChange(inputValue) {
    this.setState({
      appliedFilter: { ...this.state.appliedFilter, [inputValue.selectedColumn]: inputValue.searchEntity },
      currentPage: 1,
    });
  }

  onSearch(searchInput) {
    const filterConfig = {
      searchEntity: searchInput.searchEntity,
      selectedColumn: searchInput.selectedColumn,
    };
    const searchData = getFilterData(filterConfig, this.props.data);
    this.setState({
      data: searchData,
      currentPage: 1,
    });
  }

  onSort(columnId) {
    if (this.state.sortOrder === 'asc') {
      const sortedData = orderBy(this.state.data, [columnId], ['asc']);
      this.setState({
        data: sortedData,
        sortOrder: 'desc',
      });
    } else {
      const sortedData = orderBy(this.state.data, [columnId], ['desc']);
      this.setState({
        data: sortedData,
        sortOrder: 'asc',
      });
    }
  }

  onPagination(value) {
    const noOfPages = getNoOfPages(this.state.data, this.props.gridState.recordsPerPage);
    if (value === 'lastPage' && this.state.currentPage < noOfPages) {
      this.setState({
        currentPage: noOfPages,
      });
    }
    if (value === 'firstPage') {
      this.setState({
        currentPage: 1,
      });
    }
    if (value === 'increment' && this.state.currentPage < noOfPages) {
      this.setState({
        currentPage: this.state.currentPage + 1,
      });
    } else if (value === 'decrement' && this.state.currentPage > 1) {
      this.setState({
        currentPage: this.state.currentPage - 1,
      });
    }
  }
  renderTableDrawer(data, positions, drawerPosition) {
    return (
      <div className={`table-drawer table-drawer__${drawerPosition}`}>
        <TableDrawer
          positions={positions}
          data={data}
          metaData={this.props.metaData}
          styles={this.props.styles}
          gridState={this.props.gridState}
          onPagination={this.onPagination}
          onSearch={this.onSearch}
          onSort={this.onSort}
          currentPage={this.state.currentPage}
          recordsPerPage={this.state.recordsPerPage}
          handleReRenderButtonClick={this.handleReRenderButtonClick}
        />
      </div>
    );
    // }

    // return null;
  }

  render() {
    const { currentPage, data, recordsPerPage } = this.state;
    const filteredData = filterData(this.state.appliedFilter, this.state.data);
    const tableRowsData = getData({ data: filteredData, recordsPerPage, currentPage });
    return (
      <div className="table">
        {this.renderTableDrawer(filteredData, this.props.metaData.topDrawer, 'top')}
        <div className="render-table" style={this.props.styles.gridTable}>
          <TableHeader
            metaData={this.props.metaData.headerConfig}
            styles={this.props.styles}
            onSort={this.onSort}
            onSearch={this.onSearch}
            onFilterChange={this.onFilterChange}
            appliedFilter={this.state.appliedFilter}
          />
          <TableBody
            tableData={tableRowsData}
            metaData={this.props.metaData}
            styles={this.props.styles}
          />
        </div>
        <TableFooter
          gridState={this.props.gridState}
          metaData={this.props.metaData}
          styles={this.props.styles}
        />
        {this.renderTableDrawer(filteredData, this.props.metaData.bottomDrawer, 'bottom')}
      </div>
    );
  }
}

Table.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styles: PropTypes.object,
  gridState: PropTypes.object,
};

Table.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
  gridState: {},
};

export default Table;
